Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(883)

Unified Diff: third_party/WebKit/Source/modules/imagecapture/ImageCapture.cpp

Issue 2572603002: ABANDONED CL: Rename readyState() to getReadyState(). (Closed)
Patch Set: Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/modules/imagecapture/ImageCapture.cpp
diff --git a/third_party/WebKit/Source/modules/imagecapture/ImageCapture.cpp b/third_party/WebKit/Source/modules/imagecapture/ImageCapture.cpp
index e843453817875b3eba3ce73260d99be5fc2c060c..eafe7c086250698dea75f11fa2ad640eb99c4b21 100644
--- a/third_party/WebKit/Source/modules/imagecapture/ImageCapture.cpp
+++ b/third_party/WebKit/Source/modules/imagecapture/ImageCapture.cpp
@@ -29,9 +29,9 @@ namespace {
const char kNoServiceError[] = "ImageCapture service unavailable.";
bool trackIsInactive(const MediaStreamTrack& track) {
// Spec instructs to return an exception if the Track's readyState() is not
// "live". Also reject if the track is disabled or muted.
- return track.readyState() != "live" || !track.enabled() || track.muted();
+ return track.getReadyState() != "live" || !track.enabled() || track.muted();
}
media::mojom::blink::MeteringMode parseMeteringMode(const String& blinkMode) {
@@ -29,9 +29,9 @@ namespace {
const char kNoServiceError[] = "ImageCapture service unavailable.";
bool trackIsInactive(const MediaStreamTrack& track) {
- // Spec instructs to return an exception if the Track's readyState() is not
+ // Spec instructs to return an exception if the Track's getReadyState() is not
// "live". Also reject if the track is disabled or muted.

Powered by Google App Engine
This is Rietveld 408576698